==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/WebPubSubHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a hub.
 * @property anonymousConnectPolicy The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
 * @property eventHandlers Event handler of a hub.
 * @property eventListeners Event listener settings for forwarding your client events to listeners.
 * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
 * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
 * Maximum count of event listeners among all hubs is 10.
 */
public data class WebPubSubHubPropertiesArgs(
    public val anonymousConnectPolicy: Output<String>? = null,
    public val eventHandlers: Output<List<EventHandlerArgs>>? = null,
    public val eventListeners: Output<List<EventListenerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs =
        com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs.builder()
            .anonymousConnectPolicy(anonymousConnectPolicy?.applyValue({ args0 -> args0 }))
            .eventHandlers(
                eventHandlers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .eventListeners(
                eventListeners?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebPubSubHubPropertiesArgs].
 */
@PulumiTagMarker
public class WebPubSubHubPropertiesArgsBuilder internal constructor() {
    private var anonymousConnectPolicy: Output<String>? = null

    private var eventHandlers: Output<List<EventHandlerArgs>>? = null

    private var eventListeners: Output<List<EventListenerArgs>>? = null

    /**
     * @param value The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
     */
    @JvmName("bmnskmfysbicxdqw")
    public suspend fun anonymousConnectPolicy(`value`: Output<String>) {
        this.anonymousConnectPolicy = value
    }

    /**
     * @param value Event handler of a hub.
     */
    @JvmName("pvuuifsdoevurqer")
    public suspend fun eventHandlers(`value`: Output<List<EventHandlerArgs>>) {
        this.eventHandlers = value
    }

    @JvmName("bhhgkkrrmvetniyq")
    public suspend fun eventHandlers(vararg values: Output<EventHandlerArgs>) {
        this.eventHandlers = Output.all(values.asList())
    }

    /**
     * @param values Event handler of a hub.
     */
    @JvmName("sccuvcjgknxwypdt")
    public suspend fun eventHandlers(values: List<Output<EventHandlerArgs>>) {
        this.eventHandlers = Output.all(values)
    }

    /**
     * @param value Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("nutctjcxfxdvecge")
    public suspend fun eventListeners(`value`: Output<List<EventListenerArgs>>) {
        this.eventListeners = value
    }

    @JvmName("ihrbdggadodblenp")
    public suspend fun eventListeners(vararg values: Output<EventListenerArgs>) {
        this.eventListeners = Output.all(values.asList())
    }

    /**
     * @param values Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("agyxfoeoqncpycus")
    public suspend fun eventListeners(values: List<Output<EventListenerArgs>>) {
        this.eventListeners = Output.all(values)
    }

    /**
     * @param value The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
     */
    @JvmName("xrwlxwyrcnnfddxl")
    public suspend fun anonymousConnectPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.anonymousConnectPolicy = mapped
    }

    /**
     * @param value Event handler of a hub.
     */
    @JvmName("aydufctsypxyshnp")
    public suspend fun eventHandlers(`value`: List<EventHandlerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("wjknsuxlliafytaf")
    public suspend fun eventHandlers(argument: List<suspend EventHandlerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventHandlerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("ardhlpljgpxuruch")
    public suspend fun eventHandlers(vararg argument: suspend EventHandlerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EventHandlerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("wptahmryyudwqufi")
    public suspend fun eventHandlers(argument: suspend EventHandlerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventHandlerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param values Event handler of a hub.
     */
    @JvmName("mpykyvsnxlmnhytr")
    public suspend fun eventHandlers(vararg values: EventHandlerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventHandlers = mapped
    }

    /**
     * @param value Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("uwnjhscvalmvfkkt")
    public suspend fun eventListeners(`value`: List<EventListenerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("yddptoiryitmlxmm")
    public suspend fun eventListeners(argument: List<suspend EventListenerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("dbecvvsjfoyyjive")
    public suspend fun eventListeners(vararg argument: suspend EventListenerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EventListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("raywkfhshqncyemj")
    public suspend fun eventListeners(argument: suspend EventListenerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventListenerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param values Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("tbxpejmgctblhkwv")
    public suspend fun eventListeners(vararg values: EventListenerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventListeners = mapped
    }

    internal fun build(): WebPubSubHubPropertiesArgs = WebPubSubHubPropertiesArgs(
        anonymousConnectPolicy = anonymousConnectPolicy,
        eventHandlers = eventHandlers,
        eventListeners = eventListeners,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/WebPubSubHubPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a hub.
 * @property anonymousConnectPolicy The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
 * @property eventHandlers Event handler of a hub.
 * @property eventListeners Event listener settings for forwarding your client events to listeners.
 * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
 * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
 * Maximum count of event listeners among all hubs is 10.
 */
public data class WebPubSubHubPropertiesArgs(
    public val anonymousConnectPolicy: Output<String>? = null,
    public val eventHandlers: Output<List<EventHandlerArgs>>? = null,
    public val eventListeners: Output<List<EventListenerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs =
        com.pulumi.azurenative.webpubsub.inputs.WebPubSubHubPropertiesArgs.builder()
            .anonymousConnectPolicy(anonymousConnectPolicy?.applyValue({ args0 -> args0 }))
            .eventHandlers(
                eventHandlers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .eventListeners(
                eventListeners?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebPubSubHubPropertiesArgs].
 */
@PulumiTagMarker
public class WebPubSubHubPropertiesArgsBuilder internal constructor() {
    private var anonymousConnectPolicy: Output<String>? = null

    private var eventHandlers: Output<List<EventHandlerArgs>>? = null

    private var eventListeners: Output<List<EventListenerArgs>>? = null

    /**
     * @param value The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
     */
    @JvmName("agsflqxbywewyggg")
    public suspend fun anonymousConnectPolicy(`value`: Output<String>) {
        this.anonymousConnectPolicy = value
    }

    /**
     * @param value Event handler of a hub.
     */
    @JvmName("hwajgviraixadqxr")
    public suspend fun eventHandlers(`value`: Output<List<EventHandlerArgs>>) {
        this.eventHandlers = value
    }

    @JvmName("rrrcmiqmocudfikp")
    public suspend fun eventHandlers(vararg values: Output<EventHandlerArgs>) {
        this.eventHandlers = Output.all(values.asList())
    }

    /**
     * @param values Event handler of a hub.
     */
    @JvmName("pyrmxfmjrdhvjomv")
    public suspend fun eventHandlers(values: List<Output<EventHandlerArgs>>) {
        this.eventHandlers = Output.all(values)
    }

    /**
     * @param value Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("gprbstsamgveoknq")
    public suspend fun eventListeners(`value`: Output<List<EventListenerArgs>>) {
        this.eventListeners = value
    }

    @JvmName("vexikvimcdsqahpp")
    public suspend fun eventListeners(vararg values: Output<EventListenerArgs>) {
        this.eventListeners = Output.all(values.asList())
    }

    /**
     * @param values Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("bjcvywbaimxefnlv")
    public suspend fun eventListeners(values: List<Output<EventListenerArgs>>) {
        this.eventListeners = Output.all(values)
    }

    /**
     * @param value The settings for configuring if anonymous connections are allowed for this hub: "allow" or "deny". Default to "deny".
     */
    @JvmName("ahcrglchdcdfijvp")
    public suspend fun anonymousConnectPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.anonymousConnectPolicy = mapped
    }

    /**
     * @param value Event handler of a hub.
     */
    @JvmName("vtfpkcgvablfgrwx")
    public suspend fun eventHandlers(`value`: List<EventHandlerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("tkssetwhvblmkmka")
    public suspend fun eventHandlers(argument: List<suspend EventHandlerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventHandlerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("trocfsnhlrnyaboh")
    public suspend fun eventHandlers(vararg argument: suspend EventHandlerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EventHandlerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param argument Event handler of a hub.
     */
    @JvmName("qorvbgldsgrajpji")
    public suspend fun eventHandlers(argument: suspend EventHandlerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventHandlerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventHandlers = mapped
    }

    /**
     * @param values Event handler of a hub.
     */
    @JvmName("ciqofjpaeyseojgm")
    public suspend fun eventHandlers(vararg values: EventHandlerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventHandlers = mapped
    }

    /**
     * @param value Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("wjxitainrdpnohjx")
    public suspend fun eventListeners(`value`: List<EventListenerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("pdpereitnydyeyjs")
    public suspend fun eventListeners(argument: List<suspend EventListenerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("xgvfxjjmmfjdupur")
    public suspend fun eventListeners(vararg argument: suspend EventListenerArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EventListenerArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param argument Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("miseydkeqhxtulpr")
    public suspend fun eventListeners(argument: suspend EventListenerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventListenerArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventListeners = mapped
    }

    /**
     * @param values Event listener settings for forwarding your client events to listeners.
     * Event listener is transparent to Web PubSub clients, and it doesn't return any result to clients nor interrupt the lifetime of clients.
     * One event can be sent to multiple listeners, as long as it matches the filters in those listeners. The order of the array elements doesn't matter.
     * Maximum count of event listeners among all hubs is 10.
     */
    @JvmName("rywijbljfxhvktbw")
    public suspend fun eventListeners(vararg values: EventListenerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventListeners = mapped
    }

    internal fun build(): WebPubSubHubPropertiesArgs = WebPubSubHubPropertiesArgs(
        anonymousConnectPolicy = anonymousConnectPolicy,
        eventHandlers = eventHandlers,
        eventListeners = eventListeners,
    )
}
